summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--perl.c3
-rw-r--r--win32/perlhost.h2
-rw-r--r--win32/win32.c4
3 files changed, 6 insertions, 3 deletions
diff --git a/perl.c b/perl.c
index df306dc0e1..27936cf64e 100644
--- a/perl.c
+++ b/perl.c
@@ -2957,6 +2957,9 @@ my_exit_jump(void)
JMPENV_JUMP(2);
}
+#ifdef PERL_OBJECT
+#define NO_XSLOCKS
+#endif /* PERL_OBJECT */
#include "XSUB.h"
diff --git a/win32/perlhost.h b/win32/perlhost.h
index 729dd57670..e2d8ca70cd 100644
--- a/win32/perlhost.h
+++ b/win32/perlhost.h
@@ -661,7 +661,7 @@ public:
};
virtual int GetBufsiz(PerlIO* pf, int &err)
{
-#ifdef FILE_bufsize
+#ifdef FILE_bufsiz
FILE *f = (FILE*)pf;
return FILE_bufsiz(f);
#else
diff --git a/win32/win32.c b/win32/win32.c
index dd9fa696b9..970fc3f365 100644
--- a/win32/win32.c
+++ b/win32/win32.c
@@ -942,13 +942,13 @@ win32_getenv(const char *name)
}
else
{
/* allow any environment variables that begin with 'PERL5'
to be stored in the registry
*/
if(curitem != NULL)
*curitem = '\0';
- if (strncmp(name, "PERL5", 5) == 0) {
+ if (strncmp(name, "PERL", 4) == 0) {
if (curitem != NULL) {
Safefree(curitem);
curitem = NULL;
@@ -942,13 +942,13 @@ win32_getenv(const char *name)
else
{
- /* allow any environment variables that begin with 'PERL5'
+ /* allow any environment variables that begin with 'PERL'
to be stored in the registry
*/